#
# spec file for package mpop
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2021 Fabrice Bauzac.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _description %{expand:
mpop is a small and fast POP3 client. Features include mail filtering,
delivery to mbox files, maildir folders or a mail delivery agent, a
very fast POP3 implementation, many authentication methods, good
TLS/SSL support, IPv6 support, and more.
}
%bcond_with gnome-keyring
Name:           mpop
Version:        1.4.17
Release:        bp155.1.7
Summary:        Lightweight and featureful POP3 Client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            https://marlam.de/mpop/
Source:         https://marlam.de/mpop/releases/mpop-%{version}.tar.xz
BuildRequires:  libgsasl-devel
BuildRequires:  libidn-devel
BuildRequires:  libsecret-devel
BuildRequires:  pkgconfig
# For an unknown reason, rpmlint says:
#
#   invalid-suse-version-check 1315
#
# However, this suse_version value is actually documented in
# https://en.opensuse.org/openSUSE:Packaging_for_Leap.  Which is
# correct, rpmlint or the documentation?
%if 0%{?suse_version} > 1315
BuildRequires:  libgnutls-devel
%else
# mpop recommends gnutls over openssl:
#
#   configure: WARNING: Using OpenSSL is discouraged; consider using GnuTLS instead
#
# However, it requires gnutls >= 3.4 while SLE-12 only has 3.2.15.
#
# I see two solutions in the case of SLE-12:
# - switch to openssl
# - try using SLE-12-SP5 which might have a newer version of gnutls
#
# Let's opt for the first solution: openssl.
BuildRequires:  libopenssl-devel
%endif
%if %{with gnome-keyring}
BuildRequires:  pkgconfig(gnome-keyring-1)
%endif

%description %{_description}

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc %{_description}

This package contains documentation and sample configuration files.

%prep
%setup -q

%build
%if 0%{?suse_version} > 1000
export CFLAGS="%{optflags} -fstack-protector"
%endif

%if 0%{?suse_version} > 1315
tls_lib=gnutls
%else
tls_lib=openssl
%endif

%configure --with-tls=$tls_lib --with-libgsasl --docdir="%{_docdir}/%{name}"
%make_build -O

%install
%make_install V=1
%find_lang %{name}

for f in \
COPYING \
; do
    ff="${f##*/}"
    install -D -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$ff"
done

echo -n >docfiles.lst
for f in \
AUTHORS ChangeLog* NEWS README* THANKS NOTES \
doc/*.example \
; do
    ff="${f##*/}"
    install -D -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$ff"
    echo "%doc %{_docdir}/%{name}/$ff" >>docfiles.lst
done

%files -f %{name}.lang
%doc %dir %{_docdir}/%{name}
%license %{_docdir}/%{name}/COPYING
%{_bindir}/mpop
%{_bindir}/mpopd
%{_infodir}/mpop.info%{?ext_info}
%{_mandir}/man1/mpop.1%{?ext_man}
%{_mandir}/man1/mpopd.1%{?ext_man}

%files doc -f docfiles.lst

%changelog
* Tue Sep 13 2022 Dirk Müller <dmueller@suse.com>
- update to 1.4.17:
  - Added a new configuration command 'eval' to replace the current configuration
    file line with the output of a command (similar to passwordeval, but more
    general).
* Mon Feb 14 2022 Dirk Müller <dmueller@suse.com>
- update to 1.4.16:
  * No significant changes.
  * Added mpopd, a minimal POP3 server that delivers mails from a local mailbox
    in maildir format. It can be used by end users as a way to handle incoming
    mail via mpop with mail clients that insist on using POP3.
* Thu Nov 25 2021 Fabrice BAUZAC-STEHLY <noon@mykolab.com>
- Add support for SLE-12:
  * When building for SLE-12, switch to openssl instead of gnutls.
* Fri Sep 24 2021 noon@mykolab.com
- Update to 1.1.14.
* Tue Jan 10 2012 mrueckert@suse.com
- update to version 1.0.26:
  - No significant changes.
- additional changes from version 1.0.25:
  - DIGEST-MD5 authentication is not considered secure any longer.
    See RFC 6331.
- additional changes from version 1.0.24:
  - The build system was updated, and as a consequence some options
    to the configure script have changed. See './configure --help'.
  - The license of the manual was changed from the GNU FDL to a
    very simple permissive license.
  - Unmaintained translations (es, pt_BR) were removed.
- additional changes from version 1.0.23:
  - No significant changes.
- additional changes from version 1.0.22:
  - A new command 'received_header' with a corresponding
    '--received-header' option allows to disable the default
    Received header if required.
  - A new command 'passwordeval' with a corresponding
    '--passwordeval' option allows to set the password to the
    output of a command.
- update license tag to use the spdx format
- add support for building with gnome-keyring (disabled by default)
  call build with --with-gnome-keyring to enable it
- mpop.html is no longer shipped.
- make sure compiler cmdlines are listed (make V=1)
* Thu Jul 15 2010 pascal.bleser@opensuse.org
- update to 1.0.21:
  - No significant changes.
* Mon Mar 22 2010 pascal.bleser@opensuse.org
- update to version 1.0.20
  - Update gnulib to 2010-03-20
  - Support authentication mechanism SCRAM-SHA-1 via GNU SASL
  - New command tls_fingerprint to trust one particular TLS
    certificate
  - Change whitespace: avoid tabs and whitespace at end of lines
  - Update the documentation of keyring usage
  - Add the mpop-gnome-tool.py script to manage Gnome Keyring
    passwords for mpop (not included in this build)
  - Fix single quotes in man page
  - Add pt_BR translation
* Tue Dec  4 2007 mrueckert@suse.de
- update to version 1.0.12
  - Gnulib update to 2007-11-27.
  - Don't count already retrieved messages twice. This fixes a
    segfault when only_new is off and header or size filtering is
    on. The bug was introduced in the previous change; no released
    version is affected.
  - If a filter decides to delete a mail, then additionally mark it
    as retrieved. This prevents to filter the mail again in a later
    session when the 'keep' option is set.
  - Fix default UIDLS file on the W32 platform: Use '\' as
    directory separator, not '/'. Reported by Ricky Thomas.
- additional changes from 1.0.11
  - Update the license of the source code to GPLv3 or later, and
    change the license of the documentation to the GFDLv1.2 or
    later.
  - Gnulib update to 2007-07-15.
  - Add new option -Q / --half-quiet to print only status
    information but no progress information. Suggested by Dimitrios
    Apostolou.
  - Set the default timeout to 180 seconds = 3 minutes. This
    prevents sessions from hanging forever. Suggested by Dimitrios
    Apostolou.
  - Make the POP3 commands UIDL, LIST, and DELE abortable. This is
    useful for mailboxes with many thousand mails.
  - Update the UIDL state after mail retrieval, and save this state
    in case of errors in DELE or QUIT. Only update the UIDL state
    again after successful DELE and QUIT, and then save this state.
    This prevents an incorrect UIDL state if the DELE commands are
    aborted, for example. Bug reported by Dimitrios Apostolou.
* Thu Jun  7 2007 mrueckert@suse.de
- update to version 1.0.10
  - Fix UIDL handling: the first character of UIDs was ignored.
  - Improve APOP timestamp checks. Thanks to Carlos Martín Nieto
    for a discussion of this.
  - Add documentation on how to find the right CA certificate for
    tls_trust_file. Thanks to Bryan Kam for suggestions.
  - Improve the documentation for TLS vs. SSL and STARTTLS vs.
    POP3-over-TLS.  Thanks to Carlos Martín Nieto for suggestions.
  - Update the spanish translation (Carlos Martín Nieto).
* Tue Apr 10 2007 mrueckert@suse.de
- update to version 1.0.9
  - Security fix:
  - APOP authentication is vulnerable to man-in-the-middle
    attacks.  See CVE-2007-1558. Such attacks might lead to
    password disclosure.  Therefore, mpop does not use APOP
    automatically without TLS anymore.  Additionally, mpop's
    checks on the APOP challenge were too lax in previous
    versions, making attacks easier than necessary. This has been
    fixed.
  - Security improvements:
  - NTLM authentication is considered insecure because it is
    undocumented. It is therefore not used automatically without
    TLS anymore.
  - TLS requires tls_trust_file or a disabled tls_certcheck now,
    so that it is not silently vulnerable to man-in-the-middle
    attacks.
* Mon Mar 26 2007 mrueckert@suse.de
- update to version 1.0.8
  - Improved workarounds for POP3 servers that are not exactly RFC
    conformant.  For example, pipelining is now enabled
    automatically for pop.gmail.com and some other servers.
* Tue Jan 30 2007 mrueckert@suse.de
- update to version 1.0.7
  - Add a workaround for the Comcast.net POP3 server: allow more
    than one space before the UID in an UIDL response, even though
    RFC 1939 says it must be exactly one.
    Reported and fixed by Benji Fisher.
* Sun Jan 21 2007 mrueckert@suse.de
- update to version 1.0.6
  - Updated copyright info to 2007.
  - Added an "auto" setting for pipelining and made it the default.
    "on" and "off" now force pipelining on or off regardless of
    server capabilities.  Thanks to Jeremy C. Reed for suggestions
    on this.
  - Gnulib update to 2007-01-10.
  - Switch to autoconf-2.61 and automake-1.10, to avoid problems
    with configure trying to run "sh /usr/bin/install" where
    /usr/bin/install is not a shell script on NetBSD.
    Reported by Jeremy C. Reed.
  - Put the POP3_PIPELINE_MIN and POP3_PIPELINE_MAX definitions
    into #ifndef ...  #endif so that they can easily be set via
    CFLAGS. Thanks to Jeremy C. Reed for the patch.
  - Remove the obsolete "extern int errno;" declaration. It does
    not conform to POSIX and causes trouble.
    Thanks to Jeremy C. Reed for the patch.
  - Added AC_SYS_LARGEFILE to configure.ac, for large file support.
    Removed the unnecessary AC_C_CONST and AC_HEADER_STDC.
* Mon Nov  6 2006 mrueckert@suse.de
- update to version 1.0.5:
  Some minor build problems were fixed, and the gnulib portability
  library was updated.
* Fri Sep 29 2006 mrueckert@suse.de
- Update to version 1.0.3:
  * Improved configuration file examples in the documentation.
  * Fix GNU SASL support: replace #ifdef HAVE_GSASL with
    [#]ifdef HAVE_LIBGSASL.  The old code did not actually use GNU
    SASL. This bug was introduced in 1.0.2.
  * Prevent to write UIDLs files that we cannot read back.
  * Do not allow UIDs to start with a space.
  * Allow UIDLs file lines to be long enough to hold the longest
    UID that we would accept from a server.
  * Added spanish translation by Carlos Martín Nieto. Thanks a lot!
  * Correct the documentation of "~/.mpop_uidls" in mpop.1 and
    mpop.texi.
* Mon Aug 21 2006 mrueckert@suse.de
- Initial package from version 1.0.2
